/********************************************************
 *  ██████╗  ██████╗████████╗██╗
 * ██╔════╝ ██╔════╝╚══██╔══╝██║
 * ██║  ███╗██║        ██║   ██║
 * ██║   ██║██║        ██║   ██║
 * ╚██████╔╝╚██████╗   ██║   ███████╗
 *  ╚═════╝  ╚═════╝   ╚═╝   ╚══════╝
 * Geophysical Computational Tools & Library (GCTL)
 *
 * Copyright (c) 2022  Yi Zhang (yizhang-geo@zju.edu.cn)
 *
 * GCTL is distributed under a dual licensing scheme. You can redistribute 
 * it and/or modify it under the terms of the GNU Lesser General Public 
 * License as published by the Free Software Foundation, either version 2 
 * of the License, or (at your option) any later version. You should have 
 * received a copy of the GNU Lesser General Public License along with this 
 * program. If not, see <http://www.gnu.org/licenses/>.
 * 
 * If the terms and conditions of the LGPL v.2. would prevent you from using 
 * the GCTL, please consider the option to obtain a commercial license for a 
 * fee. These licenses are offered by the GCTL's original author. As a rule, 
 * licenses are provided "as-is", unlimited in time for a one time fee. Please 
 * send corresponding requests to: yizhang-geo@zju.edu.cn. Please do not forget 
 * to include some description of your company and the realm of its activities. 
 * Also add information on how to contact you by electronic and paper mail.
 ******************************************************/

#include "gctl/core.h"
#include "gctl/io.h"

#include "cmath"

using namespace gctl;

typedef std::vector<std::vector<double> > _2d_vector;

int main(int argc, char const *argv[])
{
	_2d_vector input_table2;
	try
	{
		gctl::text_descriptor desc;
		gctl::read_text2vector2d("data/point_height.txt", input_table2, desc);

		for (int i = 0; i < input_table2.size(); i++)
		{
			for (int j = 0; j < input_table2.at(i).size(); j++)
			{
				if (std::isnan(input_table2.at(i).at(j)))
				{
					std::cout << input_table2.at(i).at(j) << " is nan";
				}
				else if (std::isinf(input_table2.at(i).at(j)))
				{
					std::cout << input_table2.at(i).at(j) << " is inf";
				}
				else std::cout << input_table2.at(i).at(j) << " ";
			}
			std::cout << std::endl;
		}
	}
	catch (const char* err_str)
	{
		GCTL_ShowWhatError(err_str, GCTL_ERROR_ERROR, 0, 0, 0);
	}
	return 0;
}