/********************************************************
 *  ██████╗  ██████╗████████╗██╗
 * ██╔════╝ ██╔════╝╚══██╔══╝██║
 * ██║  ███╗██║        ██║   ██║
 * ██║   ██║██║        ██║   ██║
 * ╚██████╔╝╚██████╗   ██║   ███████╗
 *  ╚═════╝  ╚═════╝   ╚═╝   ╚══════╝
 * Geophysical Computational Tools & Library (GCTL)
 *
 * Copyright (c) 2022  Yi Zhang (yizhang-geo@zju.edu.cn)
 *
 * GCTL is distributed under a dual licensing scheme. You can redistribute 
 * it and/or modify it under the terms of the GNU Lesser General Public 
 * License as published by the Free Software Foundation, either version 2 
 * of the License, or (at your option) any later version. You should have 
 * received a copy of the GNU Lesser General Public License along with this 
 * program. If not, see <http://www.gnu.org/licenses/>.
 * 
 * If the terms and conditions of the LGPL v.2. would prevent you from using 
 * the GCTL, please consider the option to obtain a commercial license for a 
 * fee. These licenses are offered by the GCTL's original author. As a rule, 
 * licenses are provided "as-is", unlimited in time for a one time fee. Please 
 * send corresponding requests to: yizhang-geo@zju.edu.cn. Please do not forget 
 * to include some description of your company and the realm of its activities. 
 * Also add information on how to contact you by electronic and paper mail.
 ******************************************************/

#include "gctl/core.h"
#include "gctl/geometry.h"
#include "gctl/io.h"

using namespace gctl;

int main(int argc, char const *argv[])
{
	array<vertex2dc> nodes;
	array<triangle2d> eles;

	gmshio fio;
	fio.init_file("data/sample", Input);
	fio.set_packed(NotPacked, Input);
	fio.read_mesh(eles, nodes);

	// 使用一条直线进行切割 我们需要直线上的一个点和直线的方向向量 直线“左侧”的网络将被保留 右侧的网络将被删除
	point2dc p1(0.05, -1.0), p2(-0.65, 0.0);

	array<vertex2dc> out_nodes;
	array<triangle2d> out_eles;
	geometry2d::cut_triangular_mesh_2d(eles, p1, p2, out_nodes, out_eles);

	fio.init_file("data/out/sample_out", Output);
	fio.set_packed(NotPacked, Output);
	fio.save_mesh(out_eles, out_nodes);
	return 0;
}
