/********************************************************
 *  ██████╗  ██████╗████████╗██╗
 * ██╔════╝ ██╔════╝╚══██╔══╝██║
 * ██║  ███╗██║        ██║   ██║
 * ██║   ██║██║        ██║   ██║
 * ╚██████╔╝╚██████╗   ██║   ███████╗
 *  ╚═════╝  ╚═════╝   ╚═╝   ╚══════╝
 * Geophysical Computational Tools & Library (GCTL)
 *
 * Copyright (c) 2022  Yi Zhang (yizhang-geo@zju.edu.cn)
 *
 * GCTL is distributed under a dual licensing scheme. You can redistribute 
 * it and/or modify it under the terms of the GNU Lesser General Public 
 * License as published by the Free Software Foundation, either version 2 
 * of the License, or (at your option) any later version. You should have 
 * received a copy of the GNU Lesser General Public License along with this 
 * program. If not, see <http://www.gnu.org/licenses/>.
 * 
 * If the terms and conditions of the LGPL v.2. would prevent you from using 
 * the GCTL, please consider the option to obtain a commercial license for a 
 * fee. These licenses are offered by the GCTL's original author. As a rule, 
 * licenses are provided "as-is", unlimited in time for a one time fee. Please 
 * send corresponding requests to: yizhang-geo@zju.edu.cn. Please do not forget 
 * to include some description of your company and the realm of its activities. 
 * Also add information on how to contact you by electronic and paper mail.
 ******************************************************/

#include "gctl/core.h"
#include "gctl/geometry.h"
#include "gctl/io.h"

using namespace gctl;

int main(int argc, char const *argv[])
{
	array<vertex3dc> nodes;
	array<triangle> eles;

	gmshio fio;
	fio.init_file("data/sample3d", Input);
	fio.read_mesh(eles, nodes);

	array<vertex3dc> out_nodes;
	array<triangle> out_eles;
	point3dc nor(0, 0, -1), surf(254, 8240, 150);

	geometry3d::cut_triangular_mesh(eles, nor, surf, out_nodes, out_eles);

	fio.init_file("data/out/sample3d_out", Output);
	fio.save_mesh(out_eles, out_nodes);
	return 0;
}