/********************************************************
 *  ██████╗  ██████╗████████╗██╗
 * ██╔════╝ ██╔════╝╚══██╔══╝██║
 * ██║  ███╗██║        ██║   ██║
 * ██║   ██║██║        ██║   ██║
 * ╚██████╔╝╚██████╗   ██║   ███████╗
 *  ╚═════╝  ╚═════╝   ╚═╝   ╚══════╝
 * Geophysical Computational Tools & Library (GCTL)
 *
 * Copyright (c) 2022  Yi Zhang (yizhang-geo@zju.edu.cn)
 *
 * GCTL is distributed under a dual licensing scheme. You can redistribute 
 * it and/or modify it under the terms of the GNU Lesser General Public 
 * License as published by the Free Software Foundation, either version 2 
 * of the License, or (at your option) any later version. You should have 
 * received a copy of the GNU Lesser General Public License along with this 
 * program. If not, see <http://www.gnu.org/licenses/>.
 * 
 * If the terms and conditions of the LGPL v.2. would prevent you from using 
 * the GCTL, please consider the option to obtain a commercial license for a 
 * fee. These licenses are offered by the GCTL's original author. As a rule, 
 * licenses are provided "as-is", unlimited in time for a one time fee. Please 
 * send corresponding requests to: yizhang-geo@zju.edu.cn. Please do not forget 
 * to include some description of your company and the realm of its activities. 
 * Also add information on how to contact you by electronic and paper mail.
 ******************************************************/

#include "gctl/core.h"
#include "gctl/algorithm.h"
#include "gctl/io.h"

int main(int argc, char const *argv[])
{
	gctl::array<double> o1, o2, o3, o4;
	gctl::array<double> in(128, 0.0);
	for (int i = 0; i < in.size(); i++)
	{
		in[i] = sin(25.0*GCTL_Pi*i/360.0 + 0.2);
	}

	gctl::difference_1d(in, o1, 1.0, 1);
	gctl::difference_1d(in, o2, 1.0, 2);
	gctl::difference_1d(in, o3, 1.0, 3);
	gctl::difference_1d(in, o4, 1.0, 4);

	std::vector<std::string> head_info(1);
	head_info[0] = "ori o1 o2 o3 o4";
	gctl::save_arrays2text("data/out/difference_1d.txt", ' ', '#', 
		&head_info, nullptr, in, o1, o2, o3, o4);

	return 0;
}