/********************************************************
 *  ██████╗  ██████╗████████╗██╗
 * ██╔════╝ ██╔════╝╚══██╔══╝██║
 * ██║  ███╗██║        ██║   ██║
 * ██║   ██║██║        ██║   ██║
 * ╚██████╔╝╚██████╗   ██║   ███████╗
 *  ╚═════╝  ╚═════╝   ╚═╝   ╚══════╝
 * Geophysical Computational Tools & Library (GCTL)
 *
 * Copyright (c) 2022  Yi Zhang (yizhang-geo@zju.edu.cn)
 *
 * GCTL is distributed under a dual licensing scheme. You can redistribute 
 * it and/or modify it under the terms of the GNU Lesser General Public 
 * License as published by the Free Software Foundation, either version 2 
 * of the License, or (at your option) any later version. You should have 
 * received a copy of the GNU Lesser General Public License along with this 
 * program. If not, see <http://www.gnu.org/licenses/>.
 * 
 * If the terms and conditions of the LGPL v.2. would prevent you from using 
 * the GCTL, please consider the option to obtain a commercial license for a 
 * fee. These licenses are offered by the GCTL's original author. As a rule, 
 * licenses are provided "as-is", unlimited in time for a one time fee. Please 
 * send corresponding requests to: yizhang-geo@zju.edu.cn. Please do not forget 
 * to include some description of your company and the realm of its activities. 
 * Also add information on how to contact you by electronic and paper mail.
 ******************************************************/

#include "gctl/core.h"
#include "gctl/algorithm.h"
#include "gctl/io.h"

int main(int argc, char const *argv[])
{
	gctl::matrix<double> diff;
	gctl::matrix<double> in(128, 128, 0.0);

	double dist;
	for (int i = 0; i < in.row_size(); i++)
	{
		for (int j = 0; j < in.col_size(); j++)
		{
			dist = sqrt((i-25.0)*(i-25.0) + (j-40.0)*(j-40.0));
			in[i][j] = cos(25.0*GCTL_Pi*dist/360.0);
		}
	}

	gctl::array<double> out_data(in.row_size()*in.col_size());
	for (int i = 0; i < in.row_size(); i++)
	{
		for (int j = 0; j < in.col_size(); j++)
		{
			out_data[j + i*in.col_size()] = in[in.row_size()-1-i][j];
		}
	}

	gctl::save_netcdf_grid("data/out/difference_2d", out_data, in.col_size(), in.row_size(), 0, 1, 0, 1, "x", "y", "z");

	for (int d = 0; d < 4; d++)
	{
		gctl::difference_2d(in, diff, 1.0, gctl::Dx, d+1);
		for (int i = 0; i < in.row_size(); i++)
		{
			for (int j = 0; j < in.col_size(); j++)
			{
				out_data[j + i*in.col_size()] = diff[in.row_size()-1-i][j];
			}
		}
		gctl::append_netcdf_grid("data/out/difference_2d", out_data, "x", "y", "dx_"+std::to_string(d+1));
	}

	for (int d = 0; d < 4; d++)
	{
		gctl::difference_2d(in, diff, 1.0, gctl::Dy, d+1);
		for (int i = 0; i < in.row_size(); i++)
		{
			for (int j = 0; j < in.col_size(); j++)
			{
				out_data[j + i*in.col_size()] = diff[in.row_size()-1-i][j];
			}
		}
		gctl::append_netcdf_grid("data/out/difference_2d", out_data, "x", "y", "dy_"+std::to_string(d+1));
	}
	return 0;
}