/********************************************************
 *  ██████╗  ██████╗████████╗██╗
 * ██╔════╝ ██╔════╝╚══██╔══╝██║
 * ██║  ███╗██║        ██║   ██║
 * ██║   ██║██║        ██║   ██║
 * ╚██████╔╝╚██████╗   ██║   ███████╗
 *  ╚═════╝  ╚═════╝   ╚═╝   ╚══════╝
 * Geophysical Computational Tools & Library (GCTL)
 *
 * Copyright (c) 2022  Yi Zhang (yizhang-geo@zju.edu.cn)
 *
 * GCTL is distributed under a dual licensing scheme. You can redistribute 
 * it and/or modify it under the terms of the GNU Lesser General Public 
 * License as published by the Free Software Foundation, either version 2 
 * of the License, or (at your option) any later version. You should have 
 * received a copy of the GNU Lesser General Public License along with this 
 * program. If not, see <http://www.gnu.org/licenses/>.
 * 
 * If the terms and conditions of the LGPL v.2. would prevent you from using 
 * the GCTL, please consider the option to obtain a commercial license for a 
 * fee. These licenses are offered by the GCTL's original author. As a rule, 
 * licenses are provided "as-is", unlimited in time for a one time fee. Please 
 * send corresponding requests to: yizhang-geo@zju.edu.cn. Please do not forget 
 * to include some description of your company and the realm of its activities. 
 * Also add information on how to contact you by electronic and paper mail.
 ******************************************************/

#include "gctl/core.h"
#include "gctl/algorithm.h"

int main(int argc, char const *argv[])
{
	gctl::array<double> all_data(1000);
	gctl::random(all_data, 0.0, 2.0);

	// 计算均值和方差
	double mean = 0, stddev = 0;
	for (int i = 0; i < all_data.size(); i++)
	{
		mean += all_data[i];
	}
	mean /= all_data.size();

	for (int i = 0; i < all_data.size(); i++)
	{
		stddev += pow(all_data[i] - mean, 2.0);
	}
	stddev = sqrt(stddev/all_data.size());

	std::cout << "mean = " << mean << ", stddev = " << stddev << std::endl;

	// 计算前900个的均值和方差 然后动态计算最后100次
	mean = 0;
	stddev = 0;
	for (int i = 0; i < 900; i++)
	{
		mean += all_data[i];
	}
	mean /= 900;

	for (int i = 0; i < 900; i++)
	{
		stddev += pow(all_data[i] - mean, 2.0);
	}
	stddev = sqrt(stddev/900);

	std::cout << "mean = " << mean << ", stddev = " << stddev << std::endl;

	double new_mean;
	int count = 900;
	for (int i = 0; i < 100; i++)
	{
		stddev = gctl::dynamic_stddev(stddev, count, mean, all_data[900 + i], new_mean);
		mean = new_mean;
		std::cout << i << " mean = " << mean << ", stddev = " << stddev << std::endl;

		count++;
	}

	return 0;
}