/********************************************************
 *  ██████╗  ██████╗████████╗██╗
 * ██╔════╝ ██╔════╝╚══██╔══╝██║
 * ██║  ███╗██║        ██║   ██║
 * ██║   ██║██║        ██║   ██║
 * ╚██████╔╝╚██████╗   ██║   ███████╗
 *  ╚═════╝  ╚═════╝   ╚═╝   ╚══════╝
 * Geophysical Computational Tools & Library (GCTL)
 *
 * Copyright (c) 2022  Yi Zhang (yizhang-geo@zju.edu.cn)
 *
 * GCTL is distributed under a dual licensing scheme. You can redistribute 
 * it and/or modify it under the terms of the GNU Lesser General Public 
 * License as published by the Free Software Foundation, either version 2 
 * of the License, or (at your option) any later version. You should have 
 * received a copy of the GNU Lesser General Public License along with this 
 * program. If not, see <http://www.gnu.org/licenses/>.
 * 
 * If the terms and conditions of the LGPL v.2. would prevent you from using 
 * the GCTL, please consider the option to obtain a commercial license for a 
 * fee. These licenses are offered by the GCTL's original author. As a rule, 
 * licenses are provided "as-is", unlimited in time for a one time fee. Please 
 * send corresponding requests to: yizhang-geo@zju.edu.cn. Please do not forget 
 * to include some description of your company and the realm of its activities. 
 * Also add information on how to contact you by electronic and paper mail.
 ******************************************************/

#include "gctl/utility.h"

int main(int argc, char *argv[])
{
	try{
		int on_screen = 0;
		// 配置命令行参数与相关信息
		gctl::flags_parser fp;
		fp.set_proname("Test_Pro");
		fp.set_proinfo("This is an example of the flags_parser class.");
		fp.add_opt('i', "infile", required_argument, NULL, "Input file name.", "<filename>", true);
		fp.add_opt('o', "outfile", required_argument, NULL, "Output file name.", "<filename>", true);
		fp.add_opt('r', "range", required_argument, NULL, "Griding range.", "<xmin>/<xmax>/<ymin>/<ymax>", false);
		fp.add_opt('f', "filter", optional_argument, NULL, "Applying filter. A name may attached to the option", "[filer-name]", false);
		fp.add_opt(1, "screen", no_argument, &on_screen, "Show screen.", 0, false); // 不需要特别去拾取 只要触发getopt_long就会自动被识别
		fp.add_opt('h', "help", no_argument, NULL, "Show help information.", 0, false);
		fp.configure(argc, argv);

		if(argc == 1 || fp.set_opt("help"))
		{
			fp.show_help_page();
			return 0;
		}

		std::string in_name, out_name, range, filter;
		fp.get_argv({'i', 'o', 'r', 'f'}, {&in_name, &out_name, &range, &filter});
		if (filter == "NO_ARG") filter = "Gaussian";

		// 查看是否通过强制参数检查
		if (!fp.pass_mandatory()) return 0;

		std::cout << in_name << std::endl;
		std::cout << out_name << std::endl;
		std::cout << range << std::endl;
		std::cout << filter << std::endl;
		if (on_screen) std::cout << "-s option is set." << std::endl;
	}
	catch(std::exception &e)
	{
		GCTL_ShowWhatError(e.what(), GCTL_ERROR_ERROR, 0, 0, 0);
	}
	return 0;
}