/********************************************************
 *  ██████╗  ██████╗████████╗██╗
 * ██╔════╝ ██╔════╝╚══██╔══╝██║
 * ██║  ███╗██║        ██║   ██║
 * ██║   ██║██║        ██║   ██║
 * ╚██████╔╝╚██████╗   ██║   ███████╗
 *  ╚═════╝  ╚═════╝   ╚═╝   ╚══════╝
 * Geophysical Computational Tools & Library (GCTL)
 *
 * Copyright (c) 2022  Yi Zhang (yizhang-geo@zju.edu.cn)
 *
 * GCTL is distributed under a dual licensing scheme. You can redistribute 
 * it and/or modify it under the terms of the GNU Lesser General Public 
 * License as published by the Free Software Foundation, either version 2 
 * of the License, or (at your option) any later version. You should have 
 * received a copy of the GNU Lesser General Public License along with this 
 * program. If not, see <http://www.gnu.org/licenses/>.
 * 
 * If the terms and conditions of the LGPL v.2. would prevent you from using 
 * the GCTL, please consider the option to obtain a commercial license for a 
 * fee. These licenses are offered by the GCTL's original author. As a rule, 
 * licenses are provided "as-is", unlimited in time for a one time fee. Please 
 * send corresponding requests to: yizhang-geo@zju.edu.cn. Please do not forget 
 * to include some description of your company and the realm of its activities. 
 * Also add information on how to contact you by electronic and paper mail.
 ******************************************************/

#include "gctl/core.h"
#include "gctl/algorithm.h"
#include "gctl/utility.h"

int main(int argc, char const *argv[])
{
	gctl::gaussian_para2d p, q;

	p.mu_x = 50.0;
	p.mu_y = 40.0;
	p.sigma_x = 15.0;
	p.sigma_y = 10.0;
	p.rho = 0.2;

	q.mu_x = 60.0;
	q.mu_y = 70.0;
	q.sigma_x = 10.0;
	q.sigma_y = 20.0;
	q.rho = 0.0;

	int m = 101, n = 101;
	gctl::array<double> d(m*n, 0.0);
	gctl::array<double> dx(m*n, 0.0);
	gctl::array<double> dy(m*n, 0.0);

	for (int i = 0; i < n; i++)
	{
		for (int j = 0; j < m; j++)
		{
			d[j + i*m]  = gctl::gaussian_dist2d(1.0*j, 1.0*i, p);
			dx[j + i*m] = gctl::gaussian_dist2d(1.0*j, 1.0*i, p, gctl::Dx);
			dy[j + i*m] = gctl::gaussian_dist2d(1.0*j, 1.0*i, p, gctl::Dy);
		}
	}

	for (int i = 0; i < n; i++)
	{
		for (int j = 0; j < m; j++)
		{
			d[j + i*m]  += gctl::gaussian_dist2d(1.0*j, 1.0*i, q);
			dx[j + i*m] += gctl::gaussian_dist2d(1.0*j, 1.0*i, q, gctl::Dx);
			dy[j + i*m] += gctl::gaussian_dist2d(1.0*j, 1.0*i, q, gctl::Dy);
		}
	}

	std::ofstream outfile;
	gctl::open_outfile(outfile, "data/out/gauss_hill", ".txt");
	for (int i = 0; i < n; i++)
	{
		for (int j = 0; j < m; j++)
		{
			outfile << j << " " << i << " " << -1.0e+4*d[j + i*m] << " " << -1.0e+4*dx[j + i*m] << " " << -1.0e+4*dy[j + i*m] << std::endl;
		}
	}
	outfile.close();
	return 0;
}