/********************************************************
 *  ██████╗  ██████╗████████╗██╗
 * ██╔════╝ ██╔════╝╚══██╔══╝██║
 * ██║  ███╗██║        ██║   ██║
 * ██║   ██║██║        ██║   ██║
 * ╚██████╔╝╚██████╗   ██║   ███████╗
 *  ╚═════╝  ╚═════╝   ╚═╝   ╚══════╝
 * Geophysical Computational Tools & Library (GCTL)
 *
 * Copyright (c) 2022  Yi Zhang (yizhang-geo@zju.edu.cn)
 *
 * GCTL is distributed under a dual licensing scheme. You can redistribute 
 * it and/or modify it under the terms of the GNU Lesser General Public 
 * License as published by the Free Software Foundation, either version 2 
 * of the License, or (at your option) any later version. You should have 
 * received a copy of the GNU Lesser General Public License along with this 
 * program. If not, see <http://www.gnu.org/licenses/>.
 * 
 * If the terms and conditions of the LGPL v.2. would prevent you from using 
 * the GCTL, please consider the option to obtain a commercial license for a 
 * fee. These licenses are offered by the GCTL's original author. As a rule, 
 * licenses are provided "as-is", unlimited in time for a one time fee. Please 
 * send corresponding requests to: yizhang-geo@zju.edu.cn. Please do not forget 
 * to include some description of your company and the realm of its activities. 
 * Also add information on how to contact you by electronic and paper mail.
 ******************************************************/

#include "gctl/core.h"
#include "gctl/geometry.h"

int main(int argc, char const *argv[])
{
	gctl::point2dc a, b, c, d;
	a.set(0.0, 0.0);
	b.set(10.0, 0.0);
	c.set(5.0, 7.0);

	d.set(5.0, 5.0);
	if (gctl::geometry2d::node_in_triangle(d, a, b, c))
	{
		std::cout << "d is in triangle" << std::endl;
	}
	else std::cout << "d is not in triangle" << std::endl;

	d.set(5.0, 7.0);
	if (gctl::geometry2d::node_in_triangle(d, a, b, c, false))
	{
		std::cout << "d is in triangle" << std::endl;
	}
	else std::cout << "d is not in triangle" << std::endl;

	d.set(5.0, 8.0);
	if (gctl::geometry2d::node_in_triangle(d, a, b, c))
	{
		std::cout << "d is in triangle" << std::endl;
	}
	else std::cout << "d is not in triangle" << std::endl;

	std::cout << "---------------------" << std::endl;

	gctl::point2dc *c2, *d2;
	c2 = new gctl::point2dc;
	d2 = new gctl::point2dc;

	a.set(0.0, 0.0);
	b.set(10.0, 0.0);
	c2->set(5.0, 7.0);
	d2->set(5.0, 5.0);

	gctl::point2dc nor = d2->normal();
	std::cout << "nor(d) = (" << nor.x << ", " << nor.y << ")" << std::endl;

	gctl::point2dc e = a - b;
	std::cout << "a - b = (" << e.x << ", " << e.y << ")" << std::endl;

	double dist = gctl::distance(*c2, *d2);
	std::cout << "dist(c, d) = " << dist << std::endl;

	delete c2;
	delete d2;
	return 0;
}