/********************************************************
 *  ██████╗  ██████╗████████╗██╗
 * ██╔════╝ ██╔════╝╚══██╔══╝██║
 * ██║  ███╗██║        ██║   ██║
 * ██║   ██║██║        ██║   ██║
 * ╚██████╔╝╚██████╗   ██║   ███████╗
 *  ╚═════╝  ╚═════╝   ╚═╝   ╚══════╝
 * Geophysical Computational Tools & Library (GCTL)
 *
 * Copyright (c) 2022  Yi Zhang (yizhang-geo@zju.edu.cn)
 *
 * GCTL is distributed under a dual licensing scheme. You can redistribute 
 * it and/or modify it under the terms of the GNU Lesser General Public 
 * License as published by the Free Software Foundation, either version 2 
 * of the License, or (at your option) any later version. You should have 
 * received a copy of the GNU Lesser General Public License along with this 
 * program. If not, see <http://www.gnu.org/licenses/>.
 * 
 * If the terms and conditions of the LGPL v.2. would prevent you from using 
 * the GCTL, please consider the option to obtain a commercial license for a 
 * fee. These licenses are offered by the GCTL's original author. As a rule, 
 * licenses are provided "as-is", unlimited in time for a one time fee. Please 
 * send corresponding requests to: yizhang-geo@zju.edu.cn. Please do not forget 
 * to include some description of your company and the realm of its activities. 
 * Also add information on how to contact you by electronic and paper mail.
 ******************************************************/

#include "gctl/utility.h"

using namespace gctl;

int main(int argc, char const *argv[]) try
{
	getoption gopt;

	gopt.add_options({"range", "interval", "weight", "model-file", "model-tag", "out-model", "save-model"}, 
		{true, true, true, true, true, true, false});

	gopt.set_group(1, {"out-model", "save-model"});

	gopt.read_options("option_sample");

	gopt.check_mandatory();

	gopt.check_group(1);
	
	// 显示所有读入的键值与参数值
	gopt.show_options();
	// 通过键值获取参数值
	std::cout << gopt.get_value("model-file") << std::endl;
	// 查找不存在的命令 返回警告信息与默认值NULL
	std::cout << gopt.get_value("model-tag") << std::endl;

	std::cout << "---------------------" << std::endl;

	double weight;
	// 通过选项的标签值来获取参数值 需要匹配的字符串只需要包含标签值即可
	gctl::str2type(gopt.get_value("weight|Weight"), weight);
	std::cout << weight << std::endl;

	double xmin, xmax, ymin, ymax;
	std::string cover_str;
	parse_string_to_value(gopt.get_value("range|Range"), '/', true, xmin, xmax, ymin, ymax, cover_str);
	std::cout << xmin << " " << xmax << " " << ymin << " " << ymax << " " << cover_str << std::endl;

	std::vector<std::string> tags;
	parse_string_to_vector(gopt.get_value("model-tag"), ',', tags);
	for (int i = 0; i < tags.size(); i++)
	{
		std::cout << tags[i] << " ";
	}
	std::cout << std::endl;

	return 0;
}
catch(std::exception &e)
{
	GCTL_ShowWhatError(e.what(), GCTL_ERROR_ERROR, 0, 0, 0);
}