/********************************************************
 *  ██████╗  ██████╗████████╗██╗
 * ██╔════╝ ██╔════╝╚══██╔══╝██║
 * ██║  ███╗██║        ██║   ██║
 * ██║   ██║██║        ██║   ██║
 * ╚██████╔╝╚██████╗   ██║   ███████╗
 *  ╚═════╝  ╚═════╝   ╚═╝   ╚══════╝
 * Geophysical Computational Tools & Library (GCTL)
 *
 * Copyright (c) 2022  Yi Zhang (yizhang-geo@zju.edu.cn)
 *
 * GCTL is distributed under a dual licensing scheme. You can redistribute 
 * it and/or modify it under the terms of the GNU Lesser General Public 
 * License as published by the Free Software Foundation, either version 2 
 * of the License, or (at your option) any later version. You should have 
 * received a copy of the GNU Lesser General Public License along with this 
 * program. If not, see <http://www.gnu.org/licenses/>.
 * 
 * If the terms and conditions of the LGPL v.2. would prevent you from using 
 * the GCTL, please consider the option to obtain a commercial license for a 
 * fee. These licenses are offered by the GCTL's original author. As a rule, 
 * licenses are provided "as-is", unlimited in time for a one time fee. Please 
 * send corresponding requests to: yizhang-geo@zju.edu.cn. Please do not forget 
 * to include some description of your company and the realm of its activities. 
 * Also add information on how to contact you by electronic and paper mail.
 ******************************************************/

#include "gctl/core.h"
#include "gctl/io.h"
#include "gctl/potential.h"

using namespace gctl;

int main(int argc, char const *argv[])
{
	// set up observation parameters and polygon parameters
	array<point2dc> obes;
	linespace(point2dc(0.0, 0.0), point2dc(200.0, 0.0), 201, obes);

    array<vertex2dc> polygon(5);
    polygon[0].set(point2dc(80, -50), 0);
    polygon[1].set(point2dc(120, -50), 1);
    polygon[2].set(point2dc(120, -10), 2);
    polygon[3].set(point2dc(100, -30), 3);
    polygon[4].set(point2dc(80, -10), 4);

	array<double> g, gx, gz;
	gobser(g, polygon, obes, 1.0, Vz);
    gobser(gx, polygon, obes, 1.0, Tzx);
    gobser(gz, polygon, obes, 1.0, Tzz);

	for (int i = 0; i < obes.size(); i++)
	{
		std::cout << obes[i].x << " " << obes[i].y << " " << g[i] << " " << gx[i] << " " << gz[i] << std::endl;
	}

	return 0;
}