/********************************************************
 *  ██████╗  ██████╗████████╗██╗
 * ██╔════╝ ██╔════╝╚══██╔══╝██║
 * ██║  ███╗██║        ██║   ██║
 * ██║   ██║██║        ██║   ██║
 * ╚██████╔╝╚██████╗   ██║   ███████╗
 *  ╚═════╝  ╚═════╝   ╚═╝   ╚══════╝
 * Geophysical Computational Tools & Library (GCTL)
 *
 * Copyright (c) 2022  Yi Zhang (yizhang-geo@zju.edu.cn)
 *
 * GCTL is distributed under a dual licensing scheme. You can redistribute 
 * it and/or modify it under the terms of the GNU Lesser General Public 
 * License as published by the Free Software Foundation, either version 2 
 * of the License, or (at your option) any later version. You should have 
 * received a copy of the GNU Lesser General Public License along with this 
 * program. If not, see <http://www.gnu.org/licenses/>.
 * 
 * If the terms and conditions of the LGPL v.2. would prevent you from using 
 * the GCTL, please consider the option to obtain a commercial license for a 
 * fee. These licenses are offered by the GCTL's original author. As a rule, 
 * licenses are provided "as-is", unlimited in time for a one time fee. Please 
 * send corresponding requests to: yizhang-geo@zju.edu.cn. Please do not forget 
 * to include some description of your company and the realm of its activities. 
 * Also add information on how to contact you by electronic and paper mail.
 ******************************************************/

#include "gctl/core.h"
#include "gctl/io.h"
#include "gctl/potential.h"

int main(int argc, char const *argv[])
{
	try
	{
		// set up observation parameters and block parameters
		gctl::array<double> line_node;
		gctl::linespace(-25.0, 25.0, 201, line_node);
		gctl::array<gctl::point3ds> obes(line_node.size() * line_node.size());
		for (int i = 0; i < line_node.size(); i++)
		{
			for (int j = 0; j < line_node.size(); j++)
			{
				obes[i*line_node.size()+j].lon = line_node.at(j);
				obes[i*line_node.size()+j].lat = line_node.at(i);
				obes[i*line_node.size()+j].rad = GCTL_Earth_Radius + 100000.0;
			}
		}

		gctl::array<gctl::tesseroid> tesses(1);
		tesses[0].set(GCTL_Earth_Radius - 10000.0, GCTL_Earth_Radius - 1000.0, -2, 2, -2, 2);

		gctl::array<double> rho(1, 1.0);

		gctl::array<double> data;

#ifdef GCTL_NETCDF
		gctl::gobser(data, tesses, obes, rho, gctl::Vz, gctl::ShortMsg);
		gctl::save_netcdf_grid("data/tesseroid_gr", data, 201, 201, -25.0, 0.25, -25.0, 0.25, "x", "y", "Vr");

		gctl::gobser(data, tesses, obes, rho, gctl::Tzx, gctl::ShortMsg);
		gctl::append_netcdf_grid("data/tesseroid_gr", data, "x", "y", "Vrp");

		gctl::gobser(data, tesses, obes, rho, gctl::Tzy, gctl::ShortMsg);
		gctl::append_netcdf_grid("data/tesseroid_gr", data, "x", "y", "Vrt");
#else
		gctl::gobser(data, tesses, obes, rho, gctl::Tr, gctl::ShortMsg);
		gctl::save_surfer6_grid("data/tesseroid_gr", data, 201, 201, -25.0, 25.0, -25.0, 25.0, NAN, NAN, gctl::Surfer6Binary);
#endif // GCTL_NETCDF

	}
	catch (std::exception &e)
	{
		GCTL_ShowWhatError(e.what(), GCTL_ERROR_ERROR, 0, 0, 0);
	}
	return 0;
}