/********************************************************
 *  ██████╗  ██████╗████████╗██╗
 * ██╔════╝ ██╔════╝╚══██╔══╝██║
 * ██║  ███╗██║        ██║   ██║
 * ██║   ██║██║        ██║   ██║
 * ╚██████╔╝╚██████╗   ██║   ███████╗
 *  ╚═════╝  ╚═════╝   ╚═╝   ╚══════╝
 * Geophysical Computational Tools & Library (GCTL)
 *
 * Copyright (c) 2022  Yi Zhang (yizhang-geo@zju.edu.cn)
 *
 * GCTL is distributed under a dual licensing scheme. You can redistribute 
 * it and/or modify it under the terms of the GNU Lesser General Public 
 * License as published by the Free Software Foundation, either version 2 
 * of the License, or (at your option) any later version. You should have 
 * received a copy of the GNU Lesser General Public License along with this 
 * program. If not, see <http://www.gnu.org/licenses/>.
 * 
 * If the terms and conditions of the LGPL v.2. would prevent you from using 
 * the GCTL, please consider the option to obtain a commercial license for a 
 * fee. These licenses are offered by the GCTL's original author. As a rule, 
 * licenses are provided "as-is", unlimited in time for a one time fee. Please 
 * send corresponding requests to: yizhang-geo@zju.edu.cn. Please do not forget 
 * to include some description of your company and the realm of its activities. 
 * Also add information on how to contact you by electronic and paper mail.
 ******************************************************/

#include "gctl/potential.h"

using namespace gctl;

int main(int argc, char const *argv[])
{
	// set up observation parameters and block parameters
	array<point3ds> obes;
	gridspace(point3ds(5e+3, 30, 0), point3ds(5e+3, 50, 0), 
		point3ds(5e+3, 0, 20), point3ds(5e+3, 0, 40), 81, 81, obes);

	array<grav_tetrahedron> onetetra(1);
	array<gravtet_para> tet_gp(1);
	onetetra[0].set(point3ds(9900.0, 35.0, 25.0), point3ds(9900.0, 45.0, 30.0), 
		point3ds(9900.0, 40.0, 35.0), point3ds(9800.0, 40.0, 30.0));
	callink_gravity_para(onetetra, tet_gp);

	// set up observation array
	array<double> rho(1, 1.0);
	array<point3dc> obsval;
	gobser(obsval, onetetra, obes, rho);

	array<double> out_data(obsval.size());
	for (int i = 0; i < obsval.size(); ++i)
	{
		out_data[i] = obsval[i].x; // 球坐标下矢量第一个分量为径向分量
	}

	save_netcdf_grid("data/tetra_gr_sph", out_data, 81, 81, 30.0, 0.25, 20.0, 0.25, "longitude", "latitude", "gr");
	return 0;
}