/********************************************************
 *  ██████╗  ██████╗████████╗██╗
 * ██╔════╝ ██╔════╝╚══██╔══╝██║
 * ██║  ███╗██║        ██║   ██║
 * ██║   ██║██║        ██║   ██║
 * ╚██████╔╝╚██████╗   ██║   ███████╗
 *  ╚═════╝  ╚═════╝   ╚═╝   ╚══════╝
 * Geophysical Computational Tools & Library (GCTL)
 *
 * Copyright (c) 2022  Yi Zhang (yizhang-geo@zju.edu.cn)
 *
 * GCTL is distributed under a dual licensing scheme. You can redistribute 
 * it and/or modify it under the terms of the GNU Lesser General Public 
 * License as published by the Free Software Foundation, either version 2 
 * of the License, or (at your option) any later version. You should have 
 * received a copy of the GNU Lesser General Public License along with this 
 * program. If not, see <http://www.gnu.org/licenses/>.
 * 
 * If the terms and conditions of the LGPL v.2. would prevent you from using 
 * the GCTL, please consider the option to obtain a commercial license for a 
 * fee. These licenses are offered by the GCTL's original author. As a rule, 
 * licenses are provided "as-is", unlimited in time for a one time fee. Please 
 * send corresponding requests to: yizhang-geo@zju.edu.cn. Please do not forget 
 * to include some description of your company and the realm of its activities. 
 * Also add information on how to contact you by electronic and paper mail.
 ******************************************************/

#include "gctl/core.h"
#include "gctl/io.h"
#include "gctl/potential.h"
#include "iostream"

int main(int argc, char const *argv[])
{
	try
	{
		gctl::gm_regular_grid grav_rg;
#ifdef GCTL_NETCDF
		grav_rg.load_netcdf_grid("data/sphere_g", gctl::NodeData, 
			"x", "y");

		grav_rg.gradient("g", "gx2", gctl::Tzx, 1);
		grav_rg.gradient("g", "gy2", gctl::Tzy, 1);
		grav_rg.gradient("g", "gz2", gctl::Tzz, 1);
		grav_rg.conti("g", "g2", -50);
		grav_rg.save_netcdf_grid("data/sphere_g2", gctl::NodeData);
#else
		grav_rg.load_surfer_grid("data/sphere_g", "g", gctl::NodeData, gctl::Surfer6Binary);
		grav_rg.gradient("g", "gx", gctl::Tzx, 1);
		grav_rg.save_surfer_grid("data/sphere_gx_out", "gx", gctl::Surfer6Binary);
#endif // GCTL_NETCDF
	}
	catch (std::exception &e)
	{
		GCTL_ShowWhatError(e.what(), GCTL_ERROR_ERROR, 0, 0, 0);
	}
	return 0;
}