/********************************************************
 *  ██████╗  ██████╗████████╗██╗
 * ██╔════╝ ██╔════╝╚══██╔══╝██║
 * ██║  ███╗██║        ██║   ██║
 * ██║   ██║██║        ██║   ██║
 * ╚██████╔╝╚██████╗   ██║   ███████╗
 *  ╚═════╝  ╚═════╝   ╚═╝   ╚══════╝
 * Geophysical Computational Tools & Library (GCTL)
 *
 * Copyright (c) 2022  Yi Zhang (yizhang-geo@zju.edu.cn)
 *
 * GCTL is distributed under a dual licensing scheme. You can redistribute 
 * it and/or modify it under the terms of the GNU Lesser General Public 
 * License as published by the Free Software Foundation, either version 2 
 * of the License, or (at your option) any later version. You should have 
 * received a copy of the GNU Lesser General Public License along with this 
 * program. If not, see <http://www.gnu.org/licenses/>.
 * 
 * If the terms and conditions of the LGPL v.2. would prevent you from using 
 * the GCTL, please consider the option to obtain a commercial license for a 
 * fee. These licenses are offered by the GCTL's original author. As a rule, 
 * licenses are provided "as-is", unlimited in time for a one time fee. Please 
 * send corresponding requests to: yizhang-geo@zju.edu.cn. Please do not forget 
 * to include some description of your company and the realm of its activities. 
 * Also add information on how to contact you by electronic and paper mail.
 ******************************************************/

#include "gctl/core.h"
#include "gctl/algorithm.h"
#include "gctl/geometry.h"
#include "gctl/utility.h"

#include "iostream"

int main(int argc, char const *argv[])
{
	// declare a sort operator for double
	gctl::heap_sort<double> double_sorter;

	// test double_sorter
	int a_size = 10;
	double *A = new double [a_size];
	for (int i = 0; i < 10; i++)
	{
		A[i] = i + 1.0;
		std::cout << A[i] << " ";
	}
	std::cout << std::endl;

	// sort as a descending array
	double_sorter.execute(A, a_size, [](double *a, int l_id, int r_id)->bool{
		if (a[l_id] > a[r_id]) return true;
		else return false;
	});

	for (int i = 0; i < 10; i++)
		std::cout << A[i] << " ";
	std::cout << std::endl;

	delete[] A;

	// declare a sort operator for point3dc
	gctl::heap_sort<gctl::point3dc> p3d_sorter;

	gctl::array<gctl::point3dc> line_ps;
	gctl::linespace(gctl::point3dc(10,11,12), gctl::point3dc(0,0,0), 11, line_ps);
	for (int i = 0; i < line_ps.size(); i++)
	{
		std::cout << line_ps.at(i).x << " " << line_ps.at(i).y << " " << line_ps.at(i).z << std::endl;
	}

	// sort as an ascending array according y values
	p3d_sorter.execute(line_ps, [](gctl::array<gctl::point3dc> &a, int l_id, int r_id)->bool
	{
		if (a[l_id].y < a[r_id].y) return true;
		else return false;
	});

	for (int i = 0; i < line_ps.size(); i++)
	{
		std::cout << line_ps.at(i).x << " " << line_ps.at(i).y << " " << line_ps.at(i).z << std::endl;
	}

	return 0;
}