/********************************************************
 *  ██████╗  ██████╗████████╗██╗
 * ██╔════╝ ██╔════╝╚══██╔══╝██║
 * ██║  ███╗██║        ██║   ██║
 * ██║   ██║██║        ██║   ██║
 * ╚██████╔╝╚██████╗   ██║   ███████╗
 *  ╚═════╝  ╚═════╝   ╚═╝   ╚══════╝
 * Geophysical Computational Tools & Library (GCTL)
 *
 * Copyright (c) 2022  Yi Zhang (yizhang-geo@zju.edu.cn)
 *
 * GCTL is distributed under a dual licensing scheme. You can redistribute 
 * it and/or modify it under the terms of the GNU Lesser General Public 
 * License as published by the Free Software Foundation, either version 2 
 * of the License, or (at your option) any later version. You should have 
 * received a copy of the GNU Lesser General Public License along with this 
 * program. If not, see <http://www.gnu.org/licenses/>.
 * 
 * If the terms and conditions of the LGPL v.2. would prevent you from using 
 * the GCTL, please consider the option to obtain a commercial license for a 
 * fee. These licenses are offered by the GCTL's original author. As a rule, 
 * licenses are provided "as-is", unlimited in time for a one time fee. Please 
 * send corresponding requests to: yizhang-geo@zju.edu.cn. Please do not forget 
 * to include some description of your company and the realm of its activities. 
 * Also add information on how to contact you by electronic and paper mail.
 ******************************************************/

#include "gctl/potential.h"

using namespace gctl;

int main(int argc, char const *argv[])
{
	// 设置块体模型
	array<mag_block> bk(1);
	bk[0].set(45, 55, 45, 55, 20, 40);
	// 设置块体的磁化率与磁化参数
	array<double> sus(1, 0.1);
	array<magblock_para> mag_para(1);
	mag_para[0].inclina_deg = 60;
	mag_para[0].declina_deg = 10;
	bk[0].att = &mag_para[0];
	// 设置观测点位
	array<point3dc> obsp;
	gridspace(point3dc(0, 0, 0), point3dc(100, 0, 0), 
		point3dc(0, 0, 0), point3dc(0, 100, 0), 51, 51, obsp);
	// 正演计算
	array<double> obsval;
	magobser(obsval, bk, obsp, sus, Hax, ShortMsg);
	// 保存网格
	gctl::save_netcdf_grid("out", obsval, 51, 51, 0, 2, 0, 2, "x", "y", "Hax");

	magobser(obsval, bk, obsp, sus, Hay, ShortMsg);
	// 保存网格
	gctl::append_netcdf_grid("out", obsval, "x", "y", "Hay");

	magobser(obsval, bk, obsp, sus, Za, ShortMsg);
	// 保存网格
	gctl::append_netcdf_grid("out", obsval, "x", "y", "Za");

	gridspace(point3dc(0, 0, -5), point3dc(100, 0, -5), 
		point3dc(0, 0, -5), point3dc(0, 100, -5), 51, 51, obsp);

	magobser(obsval, bk, obsp, sus, Za, ShortMsg);
	// 保存网格
	gctl::append_netcdf_grid("out", obsval, "x", "y", "Za-10");
	return 0;
}