/********************************************************
 *  ██████╗  ██████╗████████╗██╗
 * ██╔════╝ ██╔════╝╚══██╔══╝██║
 * ██║  ███╗██║        ██║   ██║
 * ██║   ██║██║        ██║   ██║
 * ╚██████╔╝╚██████╗   ██║   ███████╗
 *  ╚═════╝  ╚═════╝   ╚═╝   ╚══════╝
 * Geophysical Computational Tools & Library (GCTL)
 *
 * Copyright (c) 2022  Yi Zhang (yizhang-geo@zju.edu.cn)
 *
 * GCTL is distributed under a dual licensing scheme. You can redistribute 
 * it and/or modify it under the terms of the GNU Lesser General Public 
 * License as published by the Free Software Foundation, either version 2 
 * of the License, or (at your option) any later version. You should have 
 * received a copy of the GNU Lesser General Public License along with this 
 * program. If not, see <http://www.gnu.org/licenses/>.
 * 
 * If the terms and conditions of the LGPL v.2. would prevent you from using 
 * the GCTL, please consider the option to obtain a commercial license for a 
 * fee. These licenses are offered by the GCTL's original author. As a rule, 
 * licenses are provided "as-is", unlimited in time for a one time fee. Please 
 * send corresponding requests to: yizhang-geo@zju.edu.cn. Please do not forget 
 * to include some description of your company and the realm of its activities. 
 * Also add information on how to contact you by electronic and paper mail.
 ******************************************************/

#include "gctl/io.h"
#include "gctl/potential.h"

using namespace gctl;

int main(int argc, char const *argv[])
{
	array<vertex3dc> node;
	array<mag_tetrahedron_ren17> ele;
	read_Tetgen_node("data/prism/prism.1", node);
	read_Tetgen_element("data/prism/prism.1", ele, node);

	array<point3dc> magz(ele.size(), point3dc(0,0,200));
	array<magtet_para_ren17> mag_para;
	callink_magnetic_para_direct(ele, mag_para, magz);

	// 设置观测点位
	array<point3dc> obsp;
	gridspace(point3dc(-30, 0, 5), point3dc(30, 0, 5), 
		point3dc(0, -30, 5), point3dc(0, 30, 5), 81, 81, obsp);
	// 正演计算
	array<double> obsval;
	array<point3dc> obsgrad;
	array<tensor> obstensor;
	magobser(obsval, ele, obsp, ShortMsg);
	// 保存网格
	gctl::save_netcdf_grid("out", obsval, 81, 81, -30.0, 0.75, -30.0, 0.75, "x", "y", "Potential");

	magobser(obsgrad, ele, obsp, ShortMsg);
	// 保存网格
	for (int i = 0; i < obsp.size(); ++i)
	{
		obsval[i] = obsgrad[i].x;
	}
	gctl::append_netcdf_grid("out", obsval, "x", "y", "Bx");

	for (int i = 0; i < obsp.size(); ++i)
	{
		obsval[i] = obsgrad[i].y;
	}
	gctl::append_netcdf_grid("out", obsval, "x", "y", "By");

	for (int i = 0; i < obsp.size(); ++i)
	{
		obsval[i] = obsgrad[i].z;
	}
	gctl::append_netcdf_grid("out", obsval, "x", "y", "Bz");


	magobser(obstensor, ele, obsp, ShortMsg);
	// 保存网格
	for (int i = 0; i < obsp.size(); ++i)
	{
		obsval[i] = obstensor[i].at(0, 0);
	}
	gctl::append_netcdf_grid("out", obsval, "x", "y", "Txx");

	for (int i = 0; i < obsp.size(); ++i)
	{
		obsval[i] = obstensor[i].at(0, 1);
	}
	gctl::append_netcdf_grid("out", obsval, "x", "y", "Txy");

	for (int i = 0; i < obsp.size(); ++i)
	{
		obsval[i] = obstensor[i].at(0, 2);
	}
	gctl::append_netcdf_grid("out", obsval, "x", "y", "Txz");

	for (int i = 0; i < obsp.size(); ++i)
	{
		obsval[i] = obstensor[i].at(1, 1);
	}
	gctl::append_netcdf_grid("out", obsval, "x", "y", "Tyy");

	for (int i = 0; i < obsp.size(); ++i)
	{
		obsval[i] = obstensor[i].at(1, 2);
	}
	gctl::append_netcdf_grid("out", obsval, "x", "y", "Tyz");

	for (int i = 0; i < obsp.size(); ++i)
	{
		obsval[i] = obstensor[i].at(2, 2);
	}
	gctl::append_netcdf_grid("out", obsval, "x", "y", "Tzz");
	return 0;
}