/********************************************************
 *  ██████╗  ██████╗████████╗██╗
 * ██╔════╝ ██╔════╝╚══██╔══╝██║
 * ██║  ███╗██║        ██║   ██║
 * ██║   ██║██║        ██║   ██║
 * ╚██████╔╝╚██████╗   ██║   ███████╗
 *  ╚═════╝  ╚═════╝   ╚═╝   ╚══════╝
 * Geophysical Computational Tools & Library (GCTL)
 *
 * Copyright (c) 2022  Yi Zhang (yizhang-geo@zju.edu.cn)
 *
 * GCTL is distributed under a dual licensing scheme. You can redistribute 
 * it and/or modify it under the terms of the GNU Lesser General Public 
 * License as published by the Free Software Foundation, either version 2 
 * of the License, or (at your option) any later version. You should have 
 * received a copy of the GNU Lesser General Public License along with this 
 * program. If not, see <http://www.gnu.org/licenses/>.
 * 
 * If the terms and conditions of the LGPL v.2. would prevent you from using 
 * the GCTL, please consider the option to obtain a commercial license for a 
 * fee. These licenses are offered by the GCTL's original author. As a rule, 
 * licenses are provided "as-is", unlimited in time for a one time fee. Please 
 * send corresponding requests to: yizhang-geo@zju.edu.cn. Please do not forget 
 * to include some description of your company and the realm of its activities. 
 * Also add information on how to contact you by electronic and paper mail.
 ******************************************************/

#include "gctl/core.h"
#include "gctl/io.h"

int main(int argc, char const *argv[])
{
	try
	{
		gctl::spmat<double> M(6, 5, 0.0);

		M.insert(3, 3, 0.5);
		M.insert(2, 3, 0.5);
		M.insert(2, 0, 0.5);
		M.insert(1, 4, 0.5);
		M.insert(0, 1, 0.5);
		M.insert(4, 2, 0.5);
		M.insert(5, 1, 0.5);
		M.insert(4, 4, 0.5);

		std::cout << "M.ele_size() = " << M.ele_size() << std::endl;

		std::cout << "M = " << std::endl;
		M.show_matrix();
		gctl::save_spmat2binary("data/out/spmat_M", M);

		gctl::spmat<double> N;
		gctl::read_binary2spmat("data/out/spmat_M", N);

		std::cout << "N = " << std::endl;
		N.show_matrix();
	}
	catch(std::exception &e)
	{
		GCTL_ShowWhatError(e.what(), GCTL_ERROR_ERROR, 0, 0, 0);
	}
	return 0;
}