/********************************************************
 *  ██████╗  ██████╗████████╗██╗
 * ██╔════╝ ██╔════╝╚══██╔══╝██║
 * ██║  ███╗██║        ██║   ██║
 * ██║   ██║██║        ██║   ██║
 * ╚██████╔╝╚██████╗   ██║   ███████╗
 *  ╚═════╝  ╚═════╝   ╚═╝   ╚══════╝
 * Geophysical Computational Tools & Library (GCTL)
 *
 * Copyright (c) 2022  Yi Zhang (yizhang-geo@zju.edu.cn)
 *
 * GCTL is distributed under a dual licensing scheme. You can redistribute 
 * it and/or modify it under the terms of the GNU Lesser General Public 
 * License as published by the Free Software Foundation, either version 2 
 * of the License, or (at your option) any later version. You should have 
 * received a copy of the GNU Lesser General Public License along with this 
 * program. If not, see <http://www.gnu.org/licenses/>.
 * 
 * If the terms and conditions of the LGPL v.2. would prevent you from using 
 * the GCTL, please consider the option to obtain a commercial license for a 
 * fee. These licenses are offered by the GCTL's original author. As a rule, 
 * licenses are provided "as-is", unlimited in time for a one time fee. Please 
 * send corresponding requests to: yizhang-geo@zju.edu.cn. Please do not forget 
 * to include some description of your company and the realm of its activities. 
 * Also add information on how to contact you by electronic and paper mail.
 ******************************************************/

#include "gctl/core.h"

int main(int argc, char const *argv[])
{
	gctl::spmat<double> M(10, 10, 0.0);

	M.insert(3, 3, 1.3);
	M.insert(5, 6, 4.6);
	M.insert(8, 1, 2.8);
	M.insert(2, 3, 7.2);
	M.insert(5, 9, 2.2);
	M.insert(2, 9, 5.4);
	M.insert(7, 4, 8.5);

	M.show_matrix();
	M.show_list();

	M.map(5, 0, 2.0);
	M.map(2, 0, 1.0);
	M.map(3, 0, 1.0, gctl::ColMajor);

	M.show_matrix();
	M.show_list();

	gctl::array<double> in(10, 0.2), out(10);
	M.multiply_vector(0, in.get(), 10, out.get());

	for (int i = 0; i < 10; i++)
	{
		std::cout << out[i] << " ";
	}
	std::cout << std::endl;
	return 0;
}