/********************************************************
 *  ██████╗  ██████╗████████╗██╗
 * ██╔════╝ ██╔════╝╚══██╔══╝██║
 * ██║  ███╗██║        ██║   ██║
 * ██║   ██║██║        ██║   ██║
 * ╚██████╔╝╚██████╗   ██║   ███████╗
 *  ╚═════╝  ╚═════╝   ╚═╝   ╚══════╝
 * Geophysical Computational Tools & Library (GCTL)
 *
 * Copyright (c) 2022  Yi Zhang (yizhang-geo@zju.edu.cn)
 *
 * GCTL is distributed under a dual licensing scheme. You can redistribute 
 * it and/or modify it under the terms of the GNU Lesser General Public 
 * License as published by the Free Software Foundation, either version 2 
 * of the License, or (at your option) any later version. You should have 
 * received a copy of the GNU Lesser General Public License along with this 
 * program. If not, see <http://www.gnu.org/licenses/>.
 * 
 * If the terms and conditions of the LGPL v.2. would prevent you from using 
 * the GCTL, please consider the option to obtain a commercial license for a 
 * fee. These licenses are offered by the GCTL's original author. As a rule, 
 * licenses are provided "as-is", unlimited in time for a one time fee. Please 
 * send corresponding requests to: yizhang-geo@zju.edu.cn. Please do not forget 
 * to include some description of your company and the realm of its activities. 
 * Also add information on how to contact you by electronic and paper mail.
 ******************************************************/

#include "gctl/core.h"
#include "gctl/geometry.h"

namespace {
// show elements
void show_tensor(const gctl::tensor &a, std::string t_name)
{
	std::cout << t_name << " = " << std::endl;
	for (int i = 0; i < 3; i++)
	{
		for (int j = 0; j < 3; j++)
		{
			std::cout << a.at(i,j) << " ";
		}
		std::cout << std::endl;
	}
	return;
}

}

int main(int argc, char const *argv[])
{
	// declare two tensors
	gctl::tensor a, b;
	for (int i = 0; i < 3; i++)
	{
		for (int j = 0; j < 3; j++)
		{
			a[i][j] = j+1;
			b[i][j] = i+1;
		}
	}

	show_tensor(a, "a");
	show_tensor(b, "b");

	// test calculations
	gctl::tensor c = a + b;
	show_tensor(c, "a+b");

	gctl::tensor d = a - b;
	show_tensor(d, "a-b");

	gctl::tensor e = a * b;
	show_tensor(e, "a*b");

	gctl::point3dc f(1.0, 2.0, 3.0);
	gctl::point3dc g = a * f;
	gctl::point3dc h = f * a;

	std::cout << "a*f = " << g.x << " " << g.y << " " << g.z << std::endl;
	std::cout << "f*a = " << h.x << " " << h.y << " " << h.z << std::endl;
	return 0;
}