/********************************************************
 *  ██████╗  ██████╗████████╗██╗
 * ██╔════╝ ██╔════╝╚══██╔══╝██║
 * ██║  ███╗██║        ██║   ██║
 * ██║   ██║██║        ██║   ██║
 * ╚██████╔╝╚██████╗   ██║   ███████╗
 *  ╚═════╝  ╚═════╝   ╚═╝   ╚══════╝
 * Geophysical Computational Tools & Library (GCTL)
 *
 * Copyright (c) 2022  Yi Zhang (yizhang-geo@zju.edu.cn)
 *
 * GCTL is distributed under a dual licensing scheme. You can redistribute 
 * it and/or modify it under the terms of the GNU Lesser General Public 
 * License as published by the Free Software Foundation, either version 2 
 * of the License, or (at your option) any later version. You should have 
 * received a copy of the GNU Lesser General Public License along with this 
 * program. If not, see <http://www.gnu.org/licenses/>.
 * 
 * If the terms and conditions of the LGPL v.2. would prevent you from using 
 * the GCTL, please consider the option to obtain a commercial license for a 
 * fee. These licenses are offered by the GCTL's original author. As a rule, 
 * licenses are provided "as-is", unlimited in time for a one time fee. Please 
 * send corresponding requests to: yizhang-geo@zju.edu.cn. Please do not forget 
 * to include some description of your company and the realm of its activities. 
 * Also add information on how to contact you by electronic and paper mail.
 ******************************************************/

#include "gctl/core.h"
#include "gctl/io.h"
#include "gctl/geometry.h"

using namespace gctl;

int main(int argc, char const *argv[]) try
{
	array<vertex3dc> nodes;
	array<tetrahedron> eles;

	gmshio fio;
	fio.init_file("data/sample_tet", Input);
	fio.set_packed(NotPacked, Input);
	fio.read_mesh(eles, nodes);

    size_t n_num = nodes.size();
    geometry3d::sort_tet_neighbor(eles, &n_num);

    for (size_t i = 0; i < eles.size(); i++)
    {
        std::clog << i << " ";
        for (size_t j = 0; j < 4; j++)
        {
            if (eles[i].neigh[j] != nullptr) std::clog << eles[i].neigh[j]->id << " ";
            else std::clog << "-1 ";
        }
        std::clog << "\n";
    }
    
	return 0;
}
catch (std::exception &e)
{
    GCTL_ShowWhatError(e.what(), GCTL_ERROR_ERROR, 0, 0, 0);
}