/********************************************************
 *  ██████╗  ██████╗████████╗██╗
 * ██╔════╝ ██╔════╝╚══██╔══╝██║
 * ██║  ███╗██║        ██║   ██║
 * ██║   ██║██║        ██║   ██║
 * ╚██████╔╝╚██████╗   ██║   ███████╗
 *  ╚═════╝  ╚═════╝   ╚═╝   ╚══════╝
 * Geophysical Computational Tools & Library (GCTL)
 *
 * Copyright (c) 2022  Yi Zhang (yizhang-geo@zju.edu.cn)
 *
 * GCTL is distributed under a dual licensing scheme. You can redistribute 
 * it and/or modify it under the terms of the GNU Lesser General Public 
 * License as published by the Free Software Foundation, either version 2 
 * of the License, or (at your option) any later version. You should have 
 * received a copy of the GNU Lesser General Public License along with this 
 * program. If not, see <http://www.gnu.org/licenses/>.
 * 
 * If the terms and conditions of the LGPL v.2. would prevent you from using 
 * the GCTL, please consider the option to obtain a commercial license for a 
 * fee. These licenses are offered by the GCTL's original author. As a rule, 
 * licenses are provided "as-is", unlimited in time for a one time fee. Please 
 * send corresponding requests to: yizhang-geo@zju.edu.cn. Please do not forget 
 * to include some description of your company and the realm of its activities. 
 * Also add information on how to contact you by electronic and paper mail.
 ******************************************************/

#include "gctl/core.h"
#include "gctl/io.h"
#include "vector"

using namespace gctl;
using namespace gctl::geometry3d;
using std::endl;

typedef std::vector<point3dc> point3dc_array;

int main(int argc, char const *argv[])
{
	//初始化两个球坐标点 比较容易设置参数
	point3ds as(1000, 30, 40), bs(800, 45, 60);
	//得到直角坐标点
	point3dc ac = as.s2c(), bc = bs.s2c();
	//等角间隔计算ac与bc之间的点的坐标
	point3dc_array mid_points;
	//把起点添加到数组
	mid_points.push_back(ac);
	//计算椭圆上点的坐标
	for (double ang = 0.001; ang < 2*GCTL_Pi; ang += 0.001)
	{
		mid_points.push_back(track_ellipse(ac,bc,ang));
	}
	//把终点添加到数组
	mid_points.push_back(bc);

	//输出到文件
	std::ofstream ofile;
	char oname[1024] = "data/out/track_ellipse_output";
	try
	{
		open_outfile(ofile, oname, ".txt");
	}
	catch(std::string err_str)
	{
		GCTL_ShowWhatError(err_str, GCTL_ERROR_ERROR, 0, 0, 0);
	}

	for (int i = 0; i < mid_points.size(); i++)
	{
		ofile << mid_points[i].x << " " << mid_points[i].y << " " << mid_points[i].z << endl;
	}
	ofile.close();
	return 0;
}