/********************************************************
 *  ██████╗  ██████╗████████╗██╗
 * ██╔════╝ ██╔════╝╚══██╔══╝██║
 * ██║  ███╗██║        ██║   ██║
 * ██║   ██║██║        ██║   ██║
 * ╚██████╔╝╚██████╗   ██║   ███████╗
 *  ╚═════╝  ╚═════╝   ╚═╝   ╚══════╝
 * Geophysical Computational Tools & Library (GCTL)
 *
 * Copyright (c) 2022  Yi Zhang (yizhang-geo@zju.edu.cn)
 *
 * GCTL is distributed under a dual licensing scheme. You can redistribute 
 * it and/or modify it under the terms of the GNU Lesser General Public 
 * License as published by the Free Software Foundation, either version 2 
 * of the License, or (at your option) any later version. You should have 
 * received a copy of the GNU Lesser General Public License along with this 
 * program. If not, see <http://www.gnu.org/licenses/>.
 * 
 * If the terms and conditions of the LGPL v.2. would prevent you from using 
 * the GCTL, please consider the option to obtain a commercial license for a 
 * fee. These licenses are offered by the GCTL's original author. As a rule, 
 * licenses are provided "as-is", unlimited in time for a one time fee. Please 
 * send corresponding requests to: yizhang-geo@zju.edu.cn. Please do not forget 
 * to include some description of your company and the realm of its activities. 
 * Also add information on how to contact you by electronic and paper mail.
 ******************************************************/

#include "gctl/core.h"
#include "gctl/io.h"

int main(int argc, char const *argv[])
{
	gctl::array<int> mesh_mark;
	gctl::array<gctl::vertex2dc> mesh_node;
	gctl::array<gctl::triangle2d> mesh_triangle;

	try
	{
		gctl::read_Triangle_node("data/sample_mesh", mesh_node, gctl::Packed, &mesh_mark);
		gctl::read_Triangle_element("data/sample_mesh", mesh_triangle, mesh_node);

		gctl::matrix<double> mesh_attri(mesh_node.size(), 3);
		for (int i = 0; i < mesh_node.size(); i++)
		{
			for (int j = 0; j < 3; j++)
			{
				mesh_attri[i][j] = -1.0 + j;
			}
		}

		gctl::matrix<double> ele_attri(mesh_triangle.size(), 3);
		for (int i = 0; i < mesh_triangle.size(); i++)
		{
			for (int j = 0; j < 3; j++)
			{
				ele_attri[i][j] = -1.0 + j;
			}
		}

		gctl::save_Triangle_node("data/out/sample_out", mesh_node, gctl::NotPacked, &mesh_mark, &mesh_attri);
		gctl::save_Triangle_element("data/out/sample_out", mesh_triangle, gctl::NotPacked, &ele_attri);

		std::ofstream outfile;
		gctl::open_outfile(outfile, "data/1", ".msh");
		gctl::save2gmsh(outfile, mesh_triangle, mesh_node);
		outfile.close();

		for (int i = 0; i < mesh_mark.size(); i++)
		{
			if (mesh_mark[i])
				std::cout << i << " ";
		}
		std::cout << std::endl;
	}
	catch(std::exception &e)
	{
		GCTL_ShowWhatError(e.what(), GCTL_ERROR_ERROR, 0, 0, 0);
	}
	return 0;
}